#ifndef MOTOR_H
#define MOTOR_H


#include <stdio.h>
#include <stdlib.h>
#include <unistd.h>
#include <sys/types.h>    
#include <sys/stat.h>    
#include <fcntl.h>

#define GPIO_PATH "/sys/class/gpio/gpio%d/value"
#define GPIO_FUNCTION_PATH "/sys/class/gpio/gpio%d/direction"
#define PWN_PATH "/sys/class/pwm/pwmchip0/pwm7/enable"   //enable

static int GPIO_Point_IN1_fd;
static int GPIO_Point_IN2_fd;
static int GPIO_Point_IN3_fd;
static int GPIO_Point_IN4_fd;
static int PWM_GPIO_fd;
//1 相正传
static unsigned char phasecw[4] = {0x08, 0x04, 0x02, 0x01};
// 1 相反转
// u8 phaseccw[4] = {0x01, 0x02, 0x04, 0x08};

// 2向 
// u8 phasecw[4] = {0x0c, 0x06, 0x03,0x09};   //正转 电机导通相序  DC-CB-BA-AD
// u8 phaseccw[4] = {0x03, 0x06, 0x0c, 0x09}; //反转 电机导通相序  AB-BC-CD-DA

// 1-2向
// u8 phasecw[8] = {0x08, 0x0c, 0x04, 0x06, 0x02, 0x03, 0x01, 0x09}; //正转 电机导通相序  D-DC-C-CB-B-BA-A-AD
// u8 phaseccw[8] = {0x01, 0x03, 0x02, 0x06, 0x04, 0x0c, 0x08, 0x89}; //反转 电机导通相序  A-AB-B-BC-C-CD-D-D

//PWM极性 normal 正常  inversed 反向
typedef enum PWM_Polarity
{
    NORMAL = 1,
    INVERSED = 0
}PWM_Polarity;

typedef struct PWMBaseInitTypeDef{
    long period;                 //周期 /  ns
    long duty_cycle;             //占空比 / ns 
    PWM_Polarity polarity;       //极性  NORMAL/INVERSED
}PWMBaseInitTypeDef;



#define GPIO_Point_IN1 2021
#define GPIO_Point_IN2 2022
#define GPIO_Point_IN3 2023
#define GPIO_Point_IN4 2024

#define GPIO_WRITEPIN(Point,value) (write(Point,value,1))

#define delay_ms(x)  (usleep(x*1000))

#define GPIO_Point_IN1_Set write(GPIO_Point_IN1_fd, "1", 1)
#define GPIO_Point_IN2_Set write(GPIO_Point_IN2_fd, "1", 1)
#define GPIO_Point_IN3_Set write(GPIO_Point_IN3_fd, "1", 1)
#define GPIO_Point_IN4_Set write(GPIO_Point_IN4_fd, "1", 1)

#define GPIO_Point_IN1_ReSet write(GPIO_Point_IN1_fd, "0", 1)
#define GPIO_Point_IN2_ReSet write(GPIO_Point_IN2_fd, "0", 1)
#define GPIO_Point_IN3_ReSet write(GPIO_Point_IN3_fd, "0", 1)
#define GPIO_Point_IN4_ReSet write(GPIO_Point_IN4_fd, "0", 1)

#define PWM_OutPut_ENABLE  write(PWM_GPIO_fd, "1", 1)
#define PWM_OutPut_DISABLE write(PWM_GPIO_fd, "0", 1)


int Motor_Init();   //步进电机及其IO初始化
int Motor_PWM_Init(PWMBaseInitTypeDef PWM_BaseStructure);  //PWM初始化函数
int Motor_PWM_Set(int enable);    //PWM状态使能设置函数

int  GPIO_WrietPin(int GPIO_Point,int GPIO_Value);   // IO 电平写入函数
void MotorCW( void );    // 步进电机转动
void MotorStop( void );  // 步进电机停止转动

#endif
